analyzer

package
v0.0.0-...-cd2c16d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package analyzer performs static analysis of a Go + Fiber project to recover its HTTP routes and request/response types, with no source annotations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Analyze

func Analyze(opts Options) (*model.API, error)

Analyze loads and analyzes the project described by opts.

Types

type Options

type Options struct {
	Dir      string   // working directory of the target project
	Patterns []string // package patterns (default ["./..."])
	Title    string
	Version  string
}

Options controls analysis.

Jump to